@@ -1,16 +1,36 @@
 
+#define PACKAGE_NAME ""
+#define PACKAGE_TARNAME ""
+#define PACKAGE_VERSION ""
+#define PACKAGE_STRING ""
+#define PACKAGE_BUGREPORT ""
+#define USE_BUILTIN_FRAME_ADDRESS 1
+#define STDC_HEADERS 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_STRING_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRINGS_H 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_STDINT_H 1
+#define HAVE_UNISTD_H 1
+#define HAVE_LONG_LONG 1
+#define HAVE_OFF_T 1
 #define SIZEOF_INT 4
 #define SIZEOF_SHORT 2
 #define SIZEOF_LONG 4
 #define SIZEOF_LONG_LONG 8
-#define SIZEOF___INT64 0
+#define SIZEOF___INT64 8
+#define SIZEOF_OFF_T 4
 #define SIZEOF_VOIDP 4
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define HAVE_STDARG_PROTOTYPES 1
-#define HAVE_ATTR_NORETURN 1
+#define NORETURN(x) x __attribute__ ((noreturn))
+#define HAVE_DECL_SYS_NERR 1
 #define HAVE_DIRENT_H 1
 #define STDC_HEADERS 1
 #define HAVE_STDLIB_H 1
@@ -23,8 +43,11 @@
 #define HAVE_SYS_TIME_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_DIRECT_H 1
+#define HAVE_SYS_UTIME_H 1
+#define HAVE_FLOAT_H 1
 #define uid_t int
 #define gid_t int
+#define HAVE_STRUCT_STAT_ST_RDEV 1
 #define HAVE_ST_RDEV 1
 #define GETGROUPS_T int
 #define RETSIGTYPE void
@@ -42,26 +65,32 @@
 #define HAVE_VSNPRINTF 1
 #define HAVE_ISNAN 1
 #define HAVE_FINITE 1
+#define HAVE_HYPOT 1
 #define HAVE_FMOD 1
 #define HAVE_WAITPID 1
-#define HAVE_GETCWD 1
+#define HAVE_FSYNC 1
 #define HAVE_CHSIZE 1
 #define HAVE_TIMES 1
 #define HAVE__SETJMP 1
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
+#define HAVE_MKTIME 1
+#define HAVE_COSH 1
+#define HAVE_SINH 1
+#define HAVE_TANH 1
 #define HAVE_DAYLIGHT 1
-#define GETPGRP_VOID 1
 #define SETPGRP_VOID 1
 #define RSHIFT(x,y) ((x)>>(int)y)
 #define FILE_COUNT _cnt
+#define FILE_READPTR _ptr
 #define NEED_IO_SEEK_BETWEEN_RW 1
+#define STACK_GROW_DIRECTION -1
 #define DEFAULT_KCODE KCODE_NONE
 #define DLEXT ".so"
 #define DLEXT2 ".dll"
-#define RUBY_LIB "/lib/ruby/1.6"
+#define RUBY_LIB "/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/lib/ruby/site_ruby"
-#define RUBY_SITE_LIB2 "/lib/ruby/site_ruby/1.6"
+#define RUBY_SITE_LIB2 "/lib/ruby/site_ruby/1.8"
 #define RUBY_PLATFORM "i386-mingw32"
-#define RUBY_ARCHLIB "/lib/ruby/1.6/i386-mingw32"
-#define RUBY_SITE_ARCHLIB "/lib/ruby/site_ruby/1.6/i386-mingw32"
+#define RUBY_ARCHLIB "/lib/ruby/1.8/i386-mingw32"
+#define RUBY_SITE_ARCHLIB "/lib/ruby/site_ruby/1.8/i386-msvcrt"
